@@ -1,6 +1,4 @@
 
-context("zip_list")
-
 test_that("can list a zip file", {
 
   dir.create(tmp <- tempfile())
@@ -12,7 +10,7 @@ test_that("can list a zip file", {
   expect_silent(
     withr::with_dir(
       dirname(tmp),
-      zip(zipfile, basename(tmp))
+      zipr(zipfile, basename(tmp))
     )
   )
 
@@ -21,11 +19,12 @@ test_that("can list a zip file", {
   list <- zip_list(zipfile)
   expect_equal(
     basename(list$filename),
-    c("file1", "file2")
+    c(basename(tmp), "file1", "file2")
   )
 
   expect_equal(
     colnames(list),
-    c("filename", "compressed_size", "uncompressed_size")
+    c("filename", "compressed_size", "uncompressed_size", "timestamp",
+      "permissions")
   )
 })
